<?php
/**
 * CleverReach WooCommerce Integration.
 *
 * @package CleverReach
 */

namespace CleverReach\WooCommerce\Components\BusinessLogicServices;

use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Entity\Recipient;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Entity\RecipientAttribute;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Interfaces\Attributes;
use CleverReach\WooCommerce\Components\Utility\Shop_Helper;

/**
 * Class Attributes_Service
 *
 * @package CleverReach\WooCommerce\Components\BusinessLogicServices
 */
class Attributes_Service implements Attributes {

	/**
	 * Array of attribute mappings.
	 *
	 * @var array
	 */
	private static $attribute_mappings = array(
		'email'          => 'Email',
		'firstname'      => 'First name',
		'lastname'       => 'Last name',
		'customernumber' => 'User ID',
		'language'       => 'Language',
		'street'         => 'Address',
		'zip'            => 'Postcode / ZIP',
		'city'           => 'City',
		'company'        => 'Company',
		'state'          => 'State / County',
		'country'        => 'Country',
		'phone'          => 'Phone',
		'newsletter'     => 'Newsletter',
		'source'         => 'Source',
		'lastorderdate'  => 'Last Order Date',
	);

	/**
	 * Get attributes from integration with translated params in system language.
	 *
	 * It should set name, description, preview_value and default_value for each attribute available in system.
	 *
	 * @return RecipientAttribute[]
	 *   List of available attributes in the system.
	 */
	public function getAttributes() {
		$recipient_attributes = array();
		$language_code = Shop_Helper::get_sync_language();
		load_textdomain( $language_code, WP_LANG_DIR . "/$language_code.mo" );
		foreach ( self::$attribute_mappings as $attribute_name => $attribute_label ) {
			$recipient_attribute = new RecipientAttribute( $attribute_name );
			$domain = $attribute_label === 'Newsletter' ? 'cleverreach-wp' : $language_code;
			$recipient_attribute->setDescription( __( $attribute_label, $domain ) );

			$recipient_attributes[] = $recipient_attribute;
		}

		return $recipient_attributes;
	}

	/**
	 * Get recipient specific attributes from integration with translated params in system language.
	 *
	 * It should set name, description, preview_value and default_value for each attribute available in system for a
	 * given Recipient entity instance.
	 *
	 *
	 * @param \CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Entity\Recipient $recipient
	 *
	 * @return RecipientAttribute[]
	 *   List of available attributes in the system for a given Recipient.
	 */
	public function getRecipientAttributes( Recipient $recipient ) {
		return $this->getAttributes();
	}
}
