<?php
/**
 * CleverReach WooCommerce Integration.
 *
 * @package CleverReach
 */

namespace CleverReach\WooCommerce\Components\BusinessLogicServices;

use CleverReach\WooCommerce\Components\Repositories\Order_Repository;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Entity\OrderItem;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Interfaces\OrderItems;

/**
 * Class Order_Items_Service
 *
 * @package CleverReach\WooCommerce\Components\BusinessLogicServices
 */
class Order_Items_Service implements OrderItems {
	/**
	 * Returns array of order items that belong to provided orders.
	 *
	 * @param string[] $order_ids List of order IDs.
	 *
	 * @return  OrderItem[]
	 *
	 * @throws \Exception Exception.
	 */
	public function getOrderItems( $order_ids ) {
		$order_repository = new Order_Repository();
		return $order_repository->get_order_items( $order_ids );
	}

	/**
	 * Returns all order items for a customer with a given email.
	 *
	 * @param string $id Customer ID.
	 *
	 * @return OrderItem[]
	 *
	 * @throws \Exception Exception.
	 */
	public function get_customer_order_items( $id ) {
		$order_repository = new Order_Repository();
		$order_ids        = $order_repository->get_customer_orders_by_id( $id );

		return $this->getOrderItems( $order_ids );
	}
}
