<?php

namespace CleverReach\WooCommerce\Components\HookHandlers;

use CleverReach\WooCommerce\Components\Utility\Database;
use CleverReach\WooCommerce\Components\Utility\Shop_Helper;
use CleverReach\WooCommerce\Components\Utility\Task_Queue;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Sync\RecipientSyncTask;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Logger\Logger;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\TaskExecution\Exceptions\QueueStorageUnavailableException;

/**
 * Class Customer_Created_Handler
 *
 * @package CleverReach\WooCommerce\Components\HookHandlers
 */
class Customer_Created_Handler extends Hook_Handler {
	/**
	 * Handles user updated or created event.
	 *
	 * @param int $user_id id of created user.
	 */
	public function handle( $user_id ) {
		if ( ! $this->should_handle_event() ) {
			return;
		}

		Logger::logInfo( 'User created event detected. User id: ' . $user_id, 'Integration' );

		$newsletter_status = ! empty( $_POST[ Database::NEWSLETTER_STATUS_FIELD ] ) ? 1 : 0;
		$this->get_recipient_repository()->update_user_newsletter_field( $user_id, $newsletter_status );

		if ( ! $this->is_initial_sync_queued() ) {
			return;
		}

		$customer_id = $this->get_customer_id_with_prefix( $user_id );
		try {
			Task_Queue::enqueue( new RecipientSyncTask( array( $customer_id ) ) );
		} catch ( QueueStorageUnavailableException $e ) {
			Logger::logError( 'Failed to enqueue recipient sync task because: ' . $e->getMessage(), 'Integration' );
		}
	}

	/**
	 * Check whether event should be handled or not.
	 *
	 * @return bool
	 */
	protected function should_handle_event() {
		return Shop_Helper::is_plugin_enabled() && Shop_Helper::is_woocommerce_active();
	}
}
