<?php

namespace CleverReach\WooCommerce\Components\HookHandlers;

use CleverReach\WooCommerce\Components\Utility\Task_Queue;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Sync\RecipientDeactivateSyncTask;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Logger\Logger;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\TaskExecution\Exceptions\QueueStorageUnavailableException;

/**
 * Class CustomerDeletedHandler
 *
 * @package CleverReach\WooCommerce\Components\HookHandlers
 */
class Customer_Deleted_Handler extends Hook_Handler {
	/**
	 * Handles users deleted event.
	 *
	 * @param int $user_id id of deleted user.
	 */
	public function handle( $user_id ) {
		if ( ! $this->should_handle_event() ) {
			return;
		}

		Logger::logInfo( 'User deleted event detected. User id: ' . $user_id, 'Integration' );

		$user = $this->get_recipient_repository()->get_user_data_by_id( $user_id );

		if ( ! empty( $user->user_email ) ) {
			try {
				Task_Queue::enqueue( new RecipientDeactivateSyncTask( array( $user->user_email ) ) );
			} catch ( QueueStorageUnavailableException $e ) {
				Logger::logError(
					'Cannot enqueue RecipientDeactivateSyncTask because:' . $e->getMessage(),
					'Integration'
				);
			}
		}
	}
}
