<?php

namespace CleverReach\WooCommerce\Components\HookHandlers;

use CleverReach\WooCommerce\Components\Utility\Task_Queue;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Sync\RecipientSyncTask;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Logger\Logger;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\TaskExecution\Exceptions\QueueStorageUnavailableException;

/**
 * Class Customer_Role_Added_Handler
 *
 * @package CleverReach\WooCommerce\Components\HookHandlers
 */
class Customer_Role_Added_Handler extends Hook_Handler {
	/**
	 * Handles user role added event.
	 *
	 * @param int      $user_id User's id.
	 * @param \WP_User $user User's new role.
	 */
	public function handle( $user_id, $user ) {
		if ( ! $this->should_handle_event() ) {
			return;
		}

		Logger::logInfo( 'Customer role changed event detected.' );

		$sync_id = $this->get_customer_id_with_prefix( $user_id );
		try {
			Task_Queue::enqueue( new RecipientSyncTask( array( $sync_id ) ) );
		} catch ( QueueStorageUnavailableException $e ) {
			Logger::logError( 'Could not enqueue recipient sync task because: ' . $e->getMessage(), 'Integration' );
		}
	}
}
