<?php
/**
 * CleverReach WooCommerce Integration.
 *
 * @package CleverReach
 */

namespace CleverReach\WooCommerce\Components\HookHandlers;

use CleverReach\WooCommerce\Components\Utility\Database;

/**
 * Class GetNewsletterFromOrderHandler
 *
 * @package CleverReach\WooCommerce\Components\HookHandlers
 */
class Get_Newsletter_From_Order_Handler extends Hook_Handler {
	/**
	 * Handles saving guest customer newsletter status.
	 *
	 * @param int $order_id ID of the order.
	 */
	public function handle( $order_id ) {
		global $wpdb;
		$database             = new Database( $wpdb );
		$current_user_id      = get_current_user_id();

		if ( 0 !== $current_user_id ) {
			// If user is logged in, newsletter status is saved to user meta table.
			update_user_meta(
				$current_user_id,
				$database->get_newsletter_column(),
				isset( $_POST[ Database::NEWSLETTER_STATUS_FIELD ] )
			);
		} else {
			// Otherwise, newsletter status is saved to the order and will be retrieved for guest customer.
			update_post_meta(
				$order_id,
				$database->get_newsletter_column(),
				isset( $_POST[ Database::NEWSLETTER_STATUS_FIELD ] )
			);
		}
	}
}
