<?php

namespace CleverReach\WooCommerce\Components\HookHandlers;

use CleverReach\WooCommerce\Components\Exceptions\Unable_To_Create_Hook_Handler_Exception;

/**
 * Class HookHandlerFactory
 *
 * @package CleverReach\WooCommerce\Components\HookHandlers
 */
class Hook_Handler_Factory {
	/**
	 * Instantiates hookhandler for a given action.
	 *
	 * @param string $action that defines what handler should be instantiated.
	 *
	 * @return Hook_Handler
	 *
	 * @throws Unable_To_Create_Hook_Handler_Exception When action is unknown.
	 */
	public static function create( $action ) {
		switch ( $action ) {
			case 'add_user_to_blog':
			case 'user_register':
				return new Customer_Created_Handler();

			case 'profile_update_single_site':
				return new Customer_Updated_Handler();

			case 'add_user_role_single_site':
				return new Customer_Role_Added_Handler();

			case 'address_updated_single_site':
				return new Customer_Address_Updated_Handler();

			case 'profile_update_multisite':
				return new Multisite_Customer_Updated_Handler();

			case 'add_user_role_multisite':
				return new Multisite_Customer_Role_Added_Handler();

			case 'address_updated_multisite':
				return new Multisite_Customer_Address_Updated_Handler();

			case 'delete_user':
			case 'remove_user_from_blog':
				return new Customer_Deleted_Handler();

			case 'update_option':
				return new Option_Changed_Handler();

			case 'order_created':
				return new Order_Created_Handler();

			case 'get_newsletter_from_order':
				return new Get_Newsletter_From_Order_Handler();

			case 'get_product':
				return new Get_Product_Handler();
		}

		throw new Unable_To_Create_Hook_Handler_Exception( 'Unknown action: ' . $action );
	}
}
