<?php

namespace CleverReach\WooCommerce\Components\HookHandlers;

use CleverReach\WooCommerce\Components\BusinessLogicServices\Recipient_Service;
use CleverReach\WooCommerce\Components\Repositories\Order_Repository;
use CleverReach\WooCommerce\Components\Repositories\Recipient_Repository;
use CleverReach\WooCommerce\Components\Utility\Shop_Helper;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Interfaces\Recipients;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Required\TaskQueueStorage;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\ServiceRegister;

/**
 * Class HookHandler
 *
 * @package CleverReach\WooCommerce\Components\HookHandlers
 */
class Hook_Handler {
	const CUSTOMER_PREFIX = 'C-';
	/**
	 * Recipient repository;
	 *
	 * @var Recipient_Repository
	 */
	protected $recipient_repository;
	/**
	 * TaskQueueStorage
	 *
	 * @var TaskQueueStorage
	 */
	protected $task_queue_storage;
	/**
	 * Recipient_Service
	 *
	 * @var Recipient_Service
	 */
	protected $recipient_service;
	/**
	 * Order_Repository
	 *
	 * @var Order_Repository
	 */
	protected $order_repository;

	/**
	 * Check whether event should be handled or not.
	 *
	 * @return bool
	 */
	protected function should_handle_event() {
		return Shop_Helper::is_plugin_enabled()
				&& $this->is_initial_sync_queued()
				&& Shop_Helper::is_woocommerce_active();
	}

	/**
	 * Checks wheter initial sync is queued or not.
	 *
	 * @return bool
	 */
	protected function is_initial_sync_queued() {
		$initial_sync = $this->get_task_queue_storage_service()->findLatestByType( 'Initial_Sync_Task' );

		/** @noinspection IsEmptyFunctionUsageInspection */
		return ! empty( $initial_sync );
	}

	/**
	 * Retrieves Recipient_Repository;
	 *
	 * @return Recipient_Repository
	 */
	protected function get_recipient_repository() {
		if ( null === $this->recipient_repository ) {
			$this->recipient_repository = new Recipient_Repository();
		}

		return $this->recipient_repository;
	}

	/**
	 * Retrieves TaskQueueStorage.
	 *
	 * @return TaskQueueStorage
	 */
	protected function get_task_queue_storage_service() {
		if ( null === $this->task_queue_storage ) {
			$this->task_queue_storage = ServiceRegister::getService( TaskQueueStorage::CLASS_NAME );
		}

		return $this->task_queue_storage;
	}

	/**
	 * Retrieves recipient service.
	 *
	 * @return Recipient_Service
	 */
	protected function get_recipients_service() {
		if ( null === $this->recipient_service ) {
			$this->recipient_service = ServiceRegister::getService( Recipients::CLASS_NAME );
		}

		return $this->recipient_service;
	}

	/**
	 * Generates prefixed id.
	 *
	 * @param int $id customer's id.
	 *
	 * @return string
	 */
	protected function get_customer_id_with_prefix( $id ) {
		return self::CUSTOMER_PREFIX . $id;
	}

	/**
	 * Retrieves order repository.
	 *
	 * @return Order_Repository
	 */
	protected function get_order_repository() {
		if ( null === $this->order_repository ) {
			$this->order_repository = new Order_Repository();
		}

		return $this->order_repository;
	}
}
