<?php

namespace CleverReach\WooCommerce\Components\HookHandlers;

use CleverReach\WooCommerce\Components\Utility\Task_Queue;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Sync\RecipientSyncTask;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Logger\Logger;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\TaskExecution\Exceptions\QueueStorageUnavailableException;

/**
 * Class Multisite_Customer_Address_Updated_Handler
 *
 * @package CleverReach\WooCommerce\Components\HookHandlers
 */
class Multisite_Customer_Address_Updated_Handler extends Hook_Handler {
	/**
	 * Handles user address updated on frontend event.
	 *
	 * @param int    $user_id      User's ID.
	 * @param string $address_type Address type (billing or shipping).
	 */
	public function handle( $user_id, $address_type ) {
		$sites = get_sites();
		foreach ( $sites as $site ) {
			switch_to_blog( $site->blog_id );
			if ( $this->should_handle_event() && is_user_member_of_blog( $user_id ) ) {
				Logger::logInfo( 'User changed event detected. User id: ' . $user_id, 'Integration' );

				$sync_id = $this->get_customer_id_with_prefix( $user_id );
				try {
					Task_Queue::enqueue( new RecipientSyncTask( array( $sync_id ) ) );
				} catch ( QueueStorageUnavailableException $e ) {
					Logger::logError( 'Could not enqueue recipient sync task because: ' . $e->getMessage(), 'Integration' );
				}
			}

			restore_current_blog();
		}
	}
}
