<?php
/**
 * CleverReach WooCommerce Integration.
 *
 * @package CleverReach
 */

namespace CleverReach\WooCommerce\Components\InfrastructureServices;

use CleverReach\WooCommerce\Components\Utility\Shop_Helper;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\LoggerAdapter;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Logger\Configuration;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Logger\LogData;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Logger\Logger;

/**
 * Class Logger_Service
 *
 * @package CleverReach\WooCommerce\Components\InfrastructureServices
 */
class Logger_Service implements LoggerAdapter {
	/**
	 * Log message in system.
	 *
	 * @param LogData $data Data to be logged.
	 */
	public function logMessage( $data ) {
		/**
		 * Configuration service.
		 *
		 * @var Configuration $config_service
		 */
		$config_service = Configuration::getInstance();
		$min_log_level  = $config_service->getMinLogLevel();
		$log_level      = $data->getLogLevel();

		if ( ! Shop_Helper::is_woocommerce_active() ) {
			return;
		}

		// min log level is actually max log level.
		if ( $log_level > $min_log_level ) {
			return;
		}

		$logger = wc_get_logger();

		$level = 'info';
		switch ( $log_level ) {
			case Logger::ERROR:
				$level = 'error';
				break;
			case Logger::WARNING:
				$level = 'warning';
				break;
			case Logger::DEBUG:
				$level = 'debug';
				break;
		}

		$log_message = '[' . $data->getComponent() . '][' . $data->getUserAccount() . '] ' . $data->getMessage() . "\n";
		$context     = array( 'source' => 'cleverreach_' . date( 'Y_m_d' ) );
		$logger->log( $level, $log_message, $context );
	}
}