<?php
/**
 * CleverReach WooCommerce Integration.
 *
 * @package CleverReach
 */

namespace CleverReach\WooCommerce\Components\Repositories;

use CleverReach\WooCommerce\Components\Utility\Database;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Required\ConfigRepositoryInterface;

/**
 * Class Config_Repository
 *
 * @package CleverReach\WooCommerce\Components\Repositories
 */
class Config_Repository extends Base_Repository implements ConfigRepositoryInterface {
	/**
	 * Config_Repository constructor.
	 */
	public function __construct() {
		parent::__construct();

		$this->table_name = self::get_table_name( Database::CONFIG_TABLE );
		$this->id_column  = 'key';
	}

	/**
	 * Getter method.
	 *
	 * @param string $key Key of configuration option.
	 *
	 * @return string | int | null
	 */
	public function get( $key ) {
		$record = $this->find_by_pk( $key );

		return ! empty( $record ) ? $record['value'] : null;
	}

	/**
	 * Setter method.
	 *
	 * @param string $key Key of configuration option.
	 * @param mixed  $value Value of configuration option.
	 *
	 * @return int | bool
	 */
	public function set( $key, $value ) {
		if ( $this->value_exists( $key ) ) {
			$result = $this->update( array( 'value' => $value ), array( 'key' => $key ) );
		} else {
			$result = $this->insert(
				array(
					'key'   => $key,
					'value' => $value,
				)
			);
		}

		return false !== $result;
	}

	/**
	 * Checks if configuration value with the provided key exists.
	 *
	 * @param string $key Key of configuration option.
	 *
	 * @return bool
	 */
	private function value_exists( $key ) {
		$config = $this->find_by_pk( $key );

		return ! empty( $config );
	}
}
