<?php
/**
 * CleverReach WooCommerce Integration.
 *
 * @package CleverReach
 */

namespace CleverReach\WooCommerce\Components\Repositories;

use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Exposed\Runnable;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Logger\Logger;
use CleverReach\WooCommerce\Components\Utility\Database;

/**
 * Class Process_Repository
 *
 * @package CleverReach\WooCommerce\Components\Repositories
 */
class Process_Repository extends Base_Repository {
	/**
	 * Process_Repository constructor.
	 */
	public function __construct() {
		parent::__construct();
		$this->table_name = self::get_table_name( Database::PROCESS_TABLE );
	}

	/**
	 * Saves process.
	 *
	 * @param string   $guid Globally Unique Identifier.
	 * @param Runnable $runner Task runner.
	 */
	public function save( $guid, Runnable $runner ) {
		$this->insert( array( 'id' => $guid, 'runner' => serialize( $runner ) ) );
	}

	/**
	 * Gets runner for provided GUID.
	 *
	 * @param string $guid Globally Unique Identifier.
	 *
	 * @return Runnable
	 *
	 * @throws \CleverReach\WooCommerce\IntegrationCore\Infrastructure\TaskExecution\Exceptions\ProcessStorageGetException Process storage exception.
	 */
	public function get_runner( $guid ) {
		$process = $this->find_by_pk( $guid );

		if ( null === $process ) {
			throw new \CleverReach\WooCommerce\IntegrationCore\Infrastructure\TaskExecution\Exceptions\ProcessStorageGetException(
				'Process runner with guid ' . $guid . ' does not exist.'
			);
		}

		return unserialize( $process['runner'] );
	}

	/**
	 * Deletes process for provided GUID.
	 *
	 * @param string $guid Globally Unique Identifier.
	 */
	public function delete_process( $guid ) {
		$process = $this->find_by_pk( $guid );

		if ( null === $process ) {
			Logger::logError( 'Could not delete process with guid ' . $guid );
		} else {
			$this->delete( array( 'id' => $guid ) );
		}
	}
}
