<?php
/**
 * CleverReach WooCommerce Integration.
 *
 * @package CleverReach
 */

namespace CleverReach\WooCommerce\Components\Sync;

use CleverReach\WooCommerce\Components\Repositories\Recipient_Repository;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Sync\BaseSyncTask;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Exceptions\InvalidConfigurationException;

/**
 * Class Default_Newsletter_Status_Sync_Task
 *
 * @package CleverReach\WooCommerce\Components\Sync
 */
class Default_Newsletter_Status_Sync_Task extends BaseSyncTask {

	/**
	 * Runs task logic
	 *
	 * @throws InvalidConfigurationException Invalid configuration exception.
	 */
	public function execute() {
		$default_newsletter_status_handling = $this->getConfigService()->get_default_newsletter_status();

		$this->reportAlive();
		$this->validate_default_newsletter_status_handling( $default_newsletter_status_handling );

		$this->reportProgress( 10 );

		$recipient_repository = new Recipient_Repository();
		$ids                  = $recipient_repository->get_users_without_newsletter_status();

		$this->reportProgress( 50 );

		$recipient_repository->insert_newsletter_values( $ids, $default_newsletter_status_handling );

		$this->reportProgress( 100 );
	}

	/**
	 * Validates if $default_newsletter_status_handling parameter is set
	 *
	 * @param string $default_newsletter_status_handling How default newsletter status handling should be done.
	 *
	 * @throws InvalidConfigurationException Invalid configuration exception.
	 */
	private function validate_default_newsletter_status_handling( $default_newsletter_status_handling ) {
		if ( ! isset( $default_newsletter_status_handling ) ) {
			throw new InvalidConfigurationException( 'Default newsletter status not set in Configuration Service' );
		}
	}
}
