<?php
/**
 * CleverReach WooCommerce Integration.
 *
 * @package CleverReach
 */

namespace CleverReach\WooCommerce\Components\Sync;

use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Sync\InitialSyncTask as BaseInitialSyncTask;

/**
 * Class Initial_Sync_Task
 *
 * @package CleverReach\WooCommerce\Components\Sync
 */
class Initial_Sync_Task extends BaseInitialSyncTask {

	/**
	 * @inheritDoc
	 */
	protected function setRecipientSyncTasks( array &$subTasks ) {
		$total_recipient_task_in_percentage = $this->calculateRecipientSyncTaskPercentageInInitialSync();

		$subTasks[ $this->getDefaultNewsletterStatusSyncTaskName() ] = $total_recipient_task_in_percentage / 2;
		$subTasks[ $this->getRecipientSyncTaskName() ]               = $total_recipient_task_in_percentage / 2;
	}

	/**
	 * @inheritDoc
	 */
	protected function getRecipientSyncTasksProgress() {
		return $this->taskProgressMap[ $this->getDefaultNewsletterStatusSyncTaskName() ] / 2 + $this->taskProgressMap[ $this->getRecipientSyncTaskName() ] / 2;
	}

	/**
	 * @inheritDoc
	 */
	protected function createSubTask( $task_key ) {
		if ( $task_key === $this->getDefaultNewsletterStatusSyncTaskName() ) {
			return $this->makeDefaultNewsletterStatusSyncTask();
		}

		return parent::createSubTask( $task_key );
	}

	/**
	 * Gets default newsletter sync task name
	 *
	 * @return string
	 */
	private function getDefaultNewsletterStatusSyncTaskName() {
		return Default_Newsletter_Status_Sync_Task::getClassName();
	}

	/**
	 * Return default newsletter sync task
	 *
	 * @return Default_Newsletter_Status_Sync_Task
	 */
	private function makeDefaultNewsletterStatusSyncTask() {
		return new Default_Newsletter_Status_Sync_Task();
	}
}
