<?php
/**
 * CleverReach WooCommerce Integration.
 *
 * @package CleverReach
 */

namespace CleverReach\WooCommerce\Components\Utility;

use CleverReach\WooCommerce\Components\BusinessLogicServices\Attributes_Service;
use CleverReach\WooCommerce\Components\BusinessLogicServices\Order_Items_Service;
use CleverReach\WooCommerce\Components\BusinessLogicServices\Recipient_Service;
use CleverReach\WooCommerce\Components\InfrastructureServices\Async_Process_Starter_Service;
use CleverReach\WooCommerce\Components\InfrastructureServices\Config_Service;
use CleverReach\WooCommerce\Components\InfrastructureServices\Http_Client_Service;
use CleverReach\WooCommerce\Components\InfrastructureServices\Logger_Service;
use CleverReach\WooCommerce\Components\InfrastructureServices\Task_Queue_Storage_Service;
use CleverReach\WooCommerce\Components\Repositories\Config_Repository;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Interfaces\Attributes;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Interfaces\OrderItems;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Interfaces\Proxy as ProxyInterface;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Interfaces\Recipients;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Proxy;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Proxy\AuthProxy;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\DefaultLoggerAdapter;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Exposed\TaskRunnerStatusStorage as TaskRunnerStatusStorageInterface;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Exposed\TaskRunnerWakeup as TaskRunnerWakeUpInterface;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Required\AsyncProcessStarter;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Required\ConfigRepositoryInterface;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Required\Configuration;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Required\HttpClient;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Required\ShopLoggerAdapter;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Required\TaskQueueStorage;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Logger\DefaultLogger;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\ServiceRegister;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\TaskExecution\Queue;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\TaskExecution\TaskRunner;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\TaskExecution\TaskRunnerStatusStorage;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\TaskExecution\TaskRunnerWakeup;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Utility\Events\EventBus;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Utility\GuidProvider;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Utility\NativeSerializer;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Utility\Serializer;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Utility\TimeProvider;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Interfaces\Notifications;
use CleverReach\WooCommerce\Components\BusinessLogicServices\Notification_Service;

/**
 * Class Initializer
 *
 * @package CleverReach\WooCommerce\Components\Utility
 */
class Initializer {
	/**
	 * Registers all services
	 */
	public static function register_services() {
		try {
			/** ********* Default CORE services ****************** */
			ServiceRegister::registerService(
				TimeProvider::CLASS_NAME,
				function () {
					return new TimeProvider();
				}
			);
			ServiceRegister::registerService(
				Queue::CLASS_NAME,
				function () {
					return new Queue();
				}
			);
			ServiceRegister::registerService(
				ProxyInterface::CLASS_NAME,
				function () {
					return new Proxy();
				}
			);
			ServiceRegister::registerService(
				AuthProxy::CLASS_NAME,
				function () {
					return new AuthProxy();
				}
			);
			ServiceRegister::registerService(
				TaskRunnerWakeUpInterface::CLASS_NAME,
				function () {
					return new TaskRunnerWakeup();
				}
			);
			ServiceRegister::registerService(
				TaskRunner::CLASS_NAME,
				function () {
					return new TaskRunner();
				}
			);
			ServiceRegister::registerService(
				GuidProvider::CLASS_NAME,
				function () {
					return new GuidProvider();
				}
			);
			ServiceRegister::registerService(
				DefaultLoggerAdapter::CLASS_NAME,
				function () {
					return new DefaultLogger();
				}
			);
			ServiceRegister::registerService(
				TaskRunnerStatusStorageInterface::CLASS_NAME,
				function () {
					return new TaskRunnerStatusStorage();
				}
			);
			ServiceRegister::registerService(
				Serializer::CLASS_NAME,
				function () {
					return new NativeSerializer();
				}
			);
			ServiceRegister::registerService(
				EventBus::CLASS_NAME,
				function () {
					return EventBus::getInstance();
				}
			);

			/** ********* Implemented services ****************** */
			ServiceRegister::registerService(
				Configuration::CLASS_NAME,
				function () {
					return new Config_Service();
				}
			);
			ServiceRegister::registerService(
				ConfigRepositoryInterface::CLASS_NAME,
				function () {
					return new Config_Repository();
				}
			);
			ServiceRegister::registerService(
				AsyncProcessStarter::CLASS_NAME,
				function () {
					return new Async_Process_Starter_Service();
				}
			);
			ServiceRegister::registerService(
				TaskQueueStorage::CLASS_NAME,
				function () {
					return new Task_Queue_Storage_Service();
				}
			);
			ServiceRegister::registerService(
				HttpClient::CLASS_NAME,
				function () {
					return new Http_Client_Service();
				}
			);
			ServiceRegister::registerService(
				ShopLoggerAdapter::CLASS_NAME,
				function () {
					return new Logger_Service();
				}
			);
			ServiceRegister::registerService(
				OrderItems::CLASS_NAME,
				function () {
					return new Order_Items_Service();
				}
			);
			ServiceRegister::registerService(
				Recipients::CLASS_NAME,
				function () {
					return new Recipient_Service();
				}
			);
			ServiceRegister::registerService(
				Attributes::CLASS_NAME,
				function () {
					return new Attributes_Service();
				}
			);
			ServiceRegister::registerService(
				Notifications::CLASS_NAME,
				function () {
					return new Notification_Service();
				}
			);
		} catch ( \InvalidArgumentException $exception ) {
			// Don't do anything if service is already registered.
		}
	}
}
