<?php
/**
 * CleverReach WooCommerce Integration.
 *
 * @package CleverReach
 */

namespace CleverReach\WooCommerce\Controllers;

use CleverReach\WooCommerce\Components\InfrastructureServices\Config_Service;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\Interfaces\Required\Configuration;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\ServiceRegister;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Class Clever_Reach_Settings_Controller
 *
 * @package CleverReach\WooCommerce\Controllers
 */
class Clever_Reach_Settings_Controller extends Clever_Reach_Base_Controller {

	/**
	 * Configuration service.
	 *
	 * @var Config_Service
	 */
	private $config_service;

	/**
	 * Gets settings
	 */
	public function get_settings() {
		$newsletter_checkbox_label = $this->get_config_service()->get_subscribe_for_newsletter_label();
		$is_checkbox_disabled      = (boolean)$this->get_config_service()->is_newsletter_checkbox_disabled();

		$this->return_json( array(
			'newsletter_checkbox_label'       => $newsletter_checkbox_label,
			'newsletter_is_checkbox_disabled' => $is_checkbox_disabled
		) );
	}

	/**
	 * Saves settings
	 */
	public function save_settings() {
		$label                = $this->get_param( 'newsletter_checkbox_label' );
		$is_checkbox_disabled = $this->get_param( 'newsletter_is_checkbox_disabled' );
		if ( empty( $label ) ) {
			$this->return_json( array( 'success' => false ) );
		}
		$this->get_config_service()->save_subscribe_for_newsletter_label( $label );
		$this->get_config_service()->save_newsletter_checkbox_disabled( $is_checkbox_disabled );

		$this->return_json( array( 'success' => true ) );
	}

	/**
	 * Returns configuration service.
	 *
	 * @return Config_Service
	 */
	private function get_config_service() {
		if ( null === $this->config_service ) {
			$this->config_service = ServiceRegister::getService( Configuration::CLASS_NAME );
		}

		return $this->config_service;
	}
}