(function () {
    document.addEventListener("DOMContentLoaded", function (event) {
        var buildFirstEmailUrl = document.getElementById('cr-build-first-email-url').value,
            retrySyncUrl = document.getElementById('cr-retry-sync-url').value,
            buildEmailUrl = document.getElementById('cr-build-email-url').value,
            buildEmailButton = document.getElementById('cr-buildEmail'),
            retrySynchronization = document.getElementById('cr-retrySync'),
            tabLinks = document.getElementsByClassName('cr-dashboard-tab'),
            checkboxLabel = document.getElementById('cr-checkbox-text'),
            checkboxErrorMessage = document.getElementById('cr-error-settings-message'),
            checkboxUpdatedMessage = document.getElementById('cr-updated-settings-message'),
            settingsSaveButton = document.getElementById('cr-settings-save-btn'),
            getSettingsUrl = document.getElementById('cr-get-settings-url').value,
            saveSettingsUrl = document.getElementById('cr-save-settings-url').value;

        setSettings(getSettingsUrl);
        settingsSaveButton.addEventListener('click', saveSettings);
        checkboxLabel.addEventListener('keyup', function () {
            this.style.width = ((this.value.length + 1) * 8) + 'px';

            if (this.value.length === 0) {
                checkboxErrorMessage.classList.remove('cr-hidden');
                settingsSaveButton.classList.add('cr-button-unclickable');
            } else {
                checkboxErrorMessage.classList.add('cr-hidden');
                settingsSaveButton.classList.remove('cr-button-unclickable');
            }
        });

        for (let i = 0; i < tabLinks.length; i++) {
            tabLinks[i].addEventListener('click', changeDashboardTab);
        }

        if (buildEmailButton) {
            buildEmailButton.addEventListener('click', function () {
                startBuildingEmail(buildEmailUrl + '#login');
            });
        } else {
            retrySynchronization.addEventListener('click', function () {
                sendAjax(retrySyncUrl);
            });
        }

        function startBuildingEmail(buildEmailUrl) {
            sendAjax(buildFirstEmailUrl);
            var win = window.open(buildEmailUrl, '_blank');
            win.focus();
        }

        function sendAjax(url, callback) {
            CleverReach.Ajax.post(url, null, function (response) {
                if (response.status === 'success') {
                    if (callback) {
                        callback();
                    } else {
                        location.reload();
                    }
                }
            }, 'json', true);
        }

        function changeDashboardTab(event) {
            for (let i = 0; i < tabLinks.length; i++) {
                tabLinks[i].className = tabLinks[i].className.replace(" active", "");
            }

            let selectedTabId = event.currentTarget.dataset.tabindex;
            event.currentTarget.className += " active";
            setActiveView(selectedTabId);
        }

        function setActiveView(tabIndex) {
            let allTabPages = document.querySelectorAll('.cr-dashboard-block');

            for (let i = 0; i < allTabPages.length; i++) {
                allTabPages[i].classList.add('cr-hidden');
            }

            let selectedTabPage = document.querySelector('.cr-dashboard-block[data-tab-index="' + tabIndex + '"]');

            selectedTabPage.classList.remove('cr-hidden');
        }

        function setSettings(url) {
            CleverReach.Ajax.get(url, null, function (response) {
                if (response && response.hasOwnProperty('newsletter_checkbox_label') && response.hasOwnProperty('newsletter_is_checkbox_disabled')) {
                    if(response.newsletter_checkbox_label){
                        checkboxLabel.value = response.newsletter_checkbox_label;
                    }
                    document.getElementById('cr-disable-checkbox').checked = response.newsletter_is_checkbox_disabled;
                }
            }, 'json', true);
        }

        function saveSettings() {
            var $isCheckboxDisabled = document.getElementById('cr-disable-checkbox').checked;
            var inputs = {
                'newsletter_checkbox_label' : checkboxLabel.value,
                'newsletter_is_checkbox_disabled' : $isCheckboxDisabled ? 1 : 0
            };

            CleverReach.Ajax.post(saveSettingsUrl, inputs, function (response) {
                if (response.success) {
                    checkboxUpdatedMessage.classList.remove('cr-hidden');
                    setTimeout(() => { checkboxUpdatedMessage.classList.add('cr-hidden'); }, 5000);
                }
                else {
                    checkboxErrorMessage.classList.remove('cr-hidden');
                    setTimeout(() => { checkboxErrorMessage.classList.add('cr-hidden'); }, 5000);
                }
            }, 'json', true);
        }
    });
})();