(function() {
    /**
     * Amount of time in seconds before the info banner appears on initial sync page.
     *
     * @type {number}
     */
    const INFO_BANNER_DELAY = 30;

    document.addEventListener("DOMContentLoaded", function() {
    
        function initialSyncCompleteHandler() {
            localStorage.removeItem('crInitialSyncStartTime');
            localStorage.removeItem('crBannerClosed');
            location.reload();
        }
    
        CleverReach.StatusChecker.init({
            statusCheckUrl: document.getElementById('cr-admin-status-check-url').value,
            baseSelector: '.cr-wc-container',
            finishedStatus: 'completed',
            onComplete: initialSyncCompleteHandler,
            pendingStatusClasses: ['cr-icofont-wait'],
            inProgressStatusClasses: ['cr-icofont-loader'],
            doneStatusClasses: ['cr-icofont-check']
        });

        if (localStorage.getItem('crInitialSyncStartTime') === null) {
            localStorage.setItem('crInitialSyncStartTime', Math.floor(Date.now()).toString());
            localStorage.setItem('crBannerClosed', false.toString());
        }

        let startTime = parseInt(localStorage.getItem('crInitialSyncStartTime')),
            isBannerClosed = localStorage.getItem('crBannerClosed') === 'true';

        if (!isBannerClosed) {
            let passedTime = (Math.floor(Date.now()) - startTime) / 1000,
                bannerContainer = document.getElementById('cr-banner-container'),
                closeBanner = bannerContainer.querySelector('.notice-dismiss');

            closeBanner.addEventListener('click', function() {
                if (!bannerContainer.classList.contains('hidden')) {
                    bannerContainer.classList.add('hidden');
                    localStorage.setItem('crBannerClosed', true.toString());
                }
            });

            if (passedTime >= INFO_BANNER_DELAY) {
                bannerContainer.classList.remove('hidden');
            } else {
                let timeout = setTimeout(function() {
                    clearTimeout(timeout);
                    bannerContainer.classList.remove('hidden');
                }, (INFO_BANNER_DELAY - passedTime) * 1000);
            }
        }
    });
})();