<?php
/**
 * CleverReach WooCommerce Integration.
 *
 * @package CleverReach
 */

use CleverReach\WooCommerce\Components\Utility\Shop_Helper;

/**
 * Frontend controller.
 *
 * @var CleverReach\WooCommerce\Controllers\Clever_Reach_Frontend_Controller $this
 */
$cr_dashboard_config = $this->get_dashboard_config();

$cr_default_checkbox_text = __( 'Sign up for our newsletter', 'cleverreach-wc' );
if ( ! $cr_dashboard_config['isInitialSyncTaskFailed'] ) {
	$cr_dashboard_title   = __( 'Targeted email marketing for more revenue!', 'cleverreach-wc' );
	$cr_dashboard_message = str_replace(
		'%s',
		$cr_dashboard_config['integrationName'],
		/* translators: %s is replaced with name of the shop*/
		__(
			'Create appealing emails to showcase your products to your customers.',
			'cleverreach-wc'
		)
	);
	$cr_segments          = $this->build_segments( $cr_dashboard_config['tags'] );
	if ( ! $cr_dashboard_config['isFirstEmailBuilt'] ) {
		$cr_dashboard_button_text = __( 'Create your first newsletter →', 'cleverreach-wc' );
	} else {
		$cr_dashboard_button_text = __( 'Create your next newsletter now! →', 'cleverreach-wc' );
	}

	$cr_import_class = ! $cr_dashboard_config['importStatisticsDisplayed'] ? 'cr-has-import' : '';
	$cr_logo         = Shop_Helper::get_clever_reach_base_url( '/resources/images/cr_logo_transparent_107px.png' );
} else {
	$cr_dashboard_title       = __( 'An error occurred!', 'cleverreach-wc' );
	$cr_dashboard_message     = str_replace(
		'%s',
		$cr_dashboard_config['initialSyncTaskFailureMessage'],
		/* translators: %s is replaced with error description */
		__( 'Error description: %s. For more details please contact Help & Support.', 'cleverreach-wc' )
	);
	$cr_dashboard_button_text = __( 'Retry synchronization now', 'cleverreach-wc' );
}
?>

<input type="hidden" id="cr-build-email-url" value="<?php echo esc_url( $cr_dashboard_config['buildEmailUrl'] ); ?>">
<input type="hidden" id="cr-build-first-email-url"
	   value="<?php echo esc_url( $cr_dashboard_config['buildFirstEmailUrl'] ); ?>">
<input type="hidden" id="cr-retry-sync-url" value="<?php echo esc_url( $cr_dashboard_config['retrySyncUrl'] ); ?>">
<input type="hidden" id="cr-get-settings-url" value="<?php echo esc_url( $cr_dashboard_config['getSettingsUrl'] ); ?>">
<input type="hidden" id="cr-save-settings-url"
	   value="<?php echo esc_url( $cr_dashboard_config['saveSettingsUrl'] ); ?>">


<div class="cr-tab-wrapper">
		<div class="cr-dashboard-tab-wrapper">
			<button class="cr-dashboard-tab active" data-tabindex="0" role="button">
				<?php echo esc_html( __( 'Dashboard', 'cleverreach-wc' ) ); ?>
			</button>
		</div>
		<div class="cr-dashboard-tab-wrapper cr-settings-tab">
			<button class="cr-dashboard-tab" data-tabindex="1" role="button">
				<?php echo esc_html( __( 'Settings', 'cleverreach-wc' ) ); ?>
			</button>
		</div>
	<div class="cr-pull-right">
		<a href="<?php echo esc_url( __( $cr_dashboard_config['helpUrl'], 'cleverreach-wc' ) ); ?>" target="_blank">
			<?php echo esc_html( __( 'Help & Support', 'cleverreach-wc' ) ); ?></a>
		<p class="cr-id"><?php echo esc_html( __( 'CleverReach® ID', 'cleverreach-wc' ) ); ?>
			: <?php echo esc_html( $cr_dashboard_config['recipientId'] ); ?></p>
	</div>
</div>

<?php if ( $cr_dashboard_config['isInitialSyncTaskFailed'] ) : ?>
	<div class="cr-content-window-wrapper">
		<div class="cr-content-window">
			<img class="cr-icon" src="<?php echo esc_url( $cr_dashboard_config['logoUrl'] ); ?>"/>
			<h3>
				<?php echo esc_html( $cr_dashboard_title ); ?>
			</h3>
			<div class="cr-dashboard-text-wrapper cr-main-text">
				<?php echo esc_html( $cr_dashboard_message ); ?>
			</div>
			<button class="cr-action-buttons-wrapper cr-primary" id="cr-retrySync">
				<?php echo esc_html( $cr_dashboard_button_text ); ?>
			</button>
		</div>
	</div>

<?php else : ?>

	<div class="cr-dashboard-block" data-tab-index="0">
		<div class="cr-dashboard-container <?php echo esc_html( $cr_import_class ); ?>">
			<?php if ( ! $cr_dashboard_config['importStatisticsDisplayed'] ) : ?>
				<!-- INITIAL SYNC IMPORT -->
				<div class="cr-import">
					<svg viewBox="0 0 400 150" preserveAspectRatio="xMinYMin meet"
						 style="stroke: none; fill: url('#cr-gradient')">
						<path d="M0,130 C150,180 200,60 400,120 L400,00 L0,0 Z" style="stroke: none;"></path>
						<defs>
							<linearGradient id="cr-gradient" x1="100%" y1="0%" x2="0%" y2="100%">
								<stop offset="0%" stop-color="#0AE355"></stop>
								<stop offset="72%" stop-color="#00C526"></stop>
							</linearGradient>
						</defs>
					</svg>
					<div class="cr-import-successful">
						<?php echo esc_html( __( 'Import was successful!', 'cleverreach-wc' ) ); ?>
					</div>
					<div class="cr-success-circle">
						<i class="fa fa-check"></i>
					</div>
					<div class="cr-report-content">
						<div class="cr-recipients">
							<div class="cr-dashboard-report-icon-large">
								<i class="fa fa-users"></i>
							</div>
							<div class="cr-dashboard-concrete-report">
								<div class="title">
									<?php echo esc_html( __( 'Recipients', 'cleverreach-wc' ) ); ?>
								</div>
								<div class="value">
									<?php
									echo esc_html( number_format_i18n( $cr_dashboard_config['numberOfSyncedRecipients'] ) );
									?>
								</div>
							</div>
						</div>
						<div class="cr-recipient-list">
							<div class="cr-dashboard-report-icon-large">
								<i class="fa fa-clipboard-list"></i>
							</div>
							<div class="cr-dashboard-concrete-report">
								<div class="title">
									<?php echo esc_html( __( 'Recipient list', 'cleverreach-wc' ) ); ?>
								</div>
								<div
										class="value cr-integration-list"
										title="<?php echo esc_html( $cr_dashboard_config['integrationListName'] ); ?>"
								>
									<?php echo esc_html( $cr_dashboard_config['integrationListName'] ); ?>
								</div>
							</div>
						</div>
						<div class="cr-segments">
							<div class="cr-dashboard-report-icon-small">
								<i class="fa fa-tag"></i>
							</div>
							<div class="cr-dashboard-concrete-report">
								<div class="title">
									<?php echo esc_html( __( 'Segments', 'cleverreach-wc' ) ); ?>
								</div>
								<?php echo $cr_segments; ?>
							</div>
						</div>
					</div>
					<div class="cr-gdpr">
						<a href="<?php echo esc_url( __( $cr_dashboard_config['gdprUrl'], 'cleverreach-wc' ) ); ?>"
						   target="_blank" class="cr-link">
							<i>
								<?php echo esc_html( __( 'Observe notes on GDPR!', 'cleverreach-wc' ) ); ?>
							</i>
						</a>
					</div>
				</div>
			<?php endif; ?>
			<!-- /INITIAL SYNC REPORT -->

			<!-- DASHBOARD CARD -->
			<div class="cr-create">
				<img class="cr-dashboard-logo" src="<?php echo esc_url( $cr_logo ); ?>" alt="Logo">
				<h3>
					<?php echo esc_html( $cr_dashboard_title ); ?>
				</h3>
				<div class="cr-dashboard-text-wrapper cr-main-text">
					<?php echo esc_html( $cr_dashboard_message ); ?>
				</div>
				<div class="cr-button-container">
					<button class="cr-action-buttons-wrapper cr-primary" id="cr-buildEmail">
						<?php echo esc_html( $cr_dashboard_button_text ); ?>
					</button>
				</div>
			</div>
			<!-- /DASHBOARD CARD -->

		</div>
	</div>
	<!-- SETTINGS CARD -->
	<div class="cr-dashboard-block cr-hidden" data-tab-index="1">
		<div class="cr-settings-container">
			<div class="wrap">
				<div id="cr-error-settings-message" class="error woocommerce-message cr-hidden">
					<p><?php echo esc_html( __( "The newsletter checkbox label can't be blank. Please enter a valid value.", 'cleverreach-wc' ) ); ?></p>
				</div>
				<div id="cr-updated-settings-message" class="updated woocommerce-message cr-hidden">
					<p><?php echo esc_html( __( "Settings saved.", 'cleverreach-wc' ) ); ?></p>
				</div>

				<div class="cr-settings-title"><?php echo esc_html( __( 'Customize newsletter checkbox', 'cleverreach-wc' ) ); ?></div>

				<table class="form-table">
					<tbody>
					<tr valign="top">
						<th scope="row" class="titledesc"><?php echo esc_html( __( 'Newsletter checkbox', 'cleverreach-wc' ) ) ?></th>
						<td class="forminp forminp-checkbox">
							<fieldset>
								<label for="cr-disable-checkbox">
									<input name="woocommerce_calc_taxes" id="cr-disable-checkbox" type="checkbox">
									<?php echo esc_html( __( 'Disable newsletter checkbox on checkout', 'cleverreach-wc' ) ) ?>
								</label>
							</fieldset>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row" class="titledesc">
							<label for="cr-checkbox-text"><?php echo esc_html( __( 'Newsletter checkbox caption', 'cleverreach-wc' ) ) ?>
								<span class="woocommerce-help-tip"></span>
							</label>
						</th>
						<td class="forminp forminp-text">
							<input name="cr-checkbox-text" id="cr-checkbox-text" type="text" class="cr-settings-input"
								   value="<?php echo esc_html( $cr_default_checkbox_text ); ?>">
						</td>
					</tr>
					</tbody>
				</table>
			</div>
			<div class="cr-settings-button-container">
				<button id="cr-settings-save-btn" name="save" class="button-primary woocommerce-save-button"
						value="<?php esc_attr_e( 'Save changes', 'cleverreach-wc' ); ?>"><?php esc_html_e( 'Save changes', 'woocommerce' ); ?></button>
			</div>
		</div>
	</div>
	<!-- /SETTINGS CARD -->
<?php endif; ?>
