<?php

namespace CleverReach\WooCommerce\IntegrationCore\BusinessLogic;

use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Scheduler\Interfaces\ScheduleRepositoryInterface;
use CleverReach\WooCommerce\IntegrationCore\BusinessLogic\Scheduler\Models\Schedule;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\ORM\Exceptions\RepositoryClassException;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\ORM\Exceptions\RepositoryNotRegisteredException;
use CleverReach\WooCommerce\IntegrationCore\Infrastructure\ORM\RepositoryRegistry as InfrastructureRepositoryRegistry;

/**
 * Class RepositoryRegistry
 *
 * @package CleverReach\WooCommerce\IntegrationCore\BusinessLogic
 */
class RepositoryRegistry extends InfrastructureRepositoryRegistry
{
    /**
     * Returns schedule repository
     *
     * @return ScheduleRepositoryInterface
     *
     * @throws RepositoryClassException
     * @throws RepositoryNotRegisteredException
     */
    public static function getScheduleRepository()
    {
        /** @var ScheduleRepositoryInterface $repository */
        $repository = static::getRepository(Schedule::getClassName());
        if (!($repository instanceof ScheduleRepositoryInterface)) {
            throw new RepositoryClassException('Instance class is not implementation of ScheduleRepositoryInterface');
        }

        return $repository;
    }
}
